================
pairwisedist
================

**Useful links:** `Documentation <https://guyteichman.github.io/pairwisedist>`_ |
`Source code <https://github.com/GuyTeichman/pairwisedist>`_ |
`Bug reports <https://github.com/GuyTeichman/pairwisedist/issues>`_ | |pipimage| | |travisci| | |downloads|

------

What is *pairwisedist*?
-------------------------

Calculate the pairwise-distance matrix for an array of *n* samples by *p* features. Currently supports the `Jackknife-correlation dissimilarity <https://doi.org/10.1101%2Fgr.9.11.1106>`_, the `Son and Baek dissimilarities <https://doi.org/10.1016/j.patrec.2007.09.015>`_ *YS1* and *YR1*, the Pearson correlation dissimilarity and the Spearman correlation dissimilarity.


How do I install *pairwisedist*?
---------------------------------
You can install *pairwisedist* via PyPI.
Use the following command in the python prompt:

.. code-block:: console

    $ pip install pairwisedist

----


.. |pipimage| image:: https://img.shields.io/pypi/v/pairwisedist.svg
        :target: https://pypi.python.org/pypi/pairwisedist
.. |downloads| image:: https://pepy.tech/badge/pairwisedist
        :target: https://pepy.tech/project/pairwisedist
..  |travisci| image:: https://travis-ci.org/GuyTeichman/pairwisedist.svg?branch=master
    :target: https://travis-ci.org/GuyTeichman/pairwisedist

